"use strict";Object.defineProperty(exports, "__esModule", {value: true}); function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; } function _nullishCoalesce(lhs, rhsFn) { if (lhs != null) { return lhs; } else { return rhsFn(); } }// lib/index.ts
var _promises = require('fs/promises');
var _posix = require('path/posix');

// lib/utils.ts
var _child_process = require('child_process'); var _child_process2 = _interopRequireDefault(_child_process);
var _crypto = require('crypto'); var _crypto2 = _interopRequireDefault(_crypto);
var _vite = require('vite');
var logger = _vite.createLogger.call(void 0, );
var hash = _nullishCoalesce(_crypto2.default.hash, () => ( ((algorithm, data, outputEncoding) => _crypto2.default.createHash(algorithm).update(data).digest(outputEncoding))));
function getHash(text, length = 8) {
  try {
    const h = hash("sha256", text, "hex").substring(0, length);
    if (length <= 64)
      return h;
    return h.padEnd(length, "_");
  } catch (e) {
    logger.error(`[getHash] - Error while creating hash: ${e}`);
    return "";
  }
}
function getGitHash() {
  try {
    return _child_process2.default.execSync("git rev-parse --short HEAD").toString().replace("\n", "");
  } catch (e) {
    logger.error(`[getGitHash] - Error while getting git hash: ${e}`);
    return "";
  }
}

// lib/index.ts
function VitePluginBuildMetaData(opts = {}) {
  const {
    fileName = "meta"
  } = opts;
  let config;
  return {
    // this name will show up in warnings and errors
    name: "vite-plugin-build-metadata",
    apply: "build",
    enforce: "post",
    configResolved(resolvedConfig) {
      config = resolvedConfig;
    },
    writeBundle: async (options, bundle) => {
      const metaFilename = `${options.dir}/${_posix.parse.call(void 0, fileName).name}.json`;
      const metaData = {
        buildHash: getHash(JSON.stringify(bundle)),
        commitHash: getGitHash(),
        date: (/* @__PURE__ */ new Date()).toJSON()
      };
      await _promises.writeFile.call(void 0, 
        metaFilename,
        JSON.stringify(metaData, null, 2)
      );
      config.logger.info(`
\u2728 [vite-plugin-build-metadata] - Hash has been created in ${fileName}.json
`);
    }
  };
}





exports.VitePluginBuildMetaData = VitePluginBuildMetaData; exports.default = VitePluginBuildMetaData; exports.getGitHash = getGitHash; exports.getHash = getHash;
